/*
 *  playlist-flac.h
 *  mod_musicindex
 *
 *  $Id: playlist-flac.h 1010 2012-08-07 13:38:34Z varenet $
 *
 *  Created by Regis BOUDIN on Thu Jun 30 2004.
 *  Copyright (c) 2004 Regis BOUDIN
 *   
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */
 
#ifndef PLAYLIST_FLAC_H
#define PLAYLIST_FLAC_H

#include "mod_musicindex.h"

mu_ent *make_flac_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
	const char *const filename);
#endif
